@@ -3,10 +3,11 @@ from .assign_result import AssignResult
 from .atss_assigner import ATSSAssigner
 from .base_assigner import BaseAssigner
 from .center_region_assigner import CenterRegionAssigner
+from .grid_assigner import GridAssigner
 from .max_iou_assigner import MaxIoUAssigner
 from .point_assigner import PointAssigner
 
 __all__ = [
     'BaseAssigner', 'MaxIoUAssigner', 'ApproxMaxIoUAssigner', 'AssignResult',
-    'PointAssigner', 'ATSSAssigner', 'CenterRegionAssigner'
+    'PointAssigner', 'ATSSAssigner', 'CenterRegionAssigner', 'GridAssigner'
 ]
