@@ -76,5 +76,7 @@ class SingleRoIExtractor(BaseRoIExtractor):
                 roi_feats_t = self.roi_layers[i](feats[i], rois_)
                 roi_feats[inds] = roi_feats_t
             else:
-                roi_feats += sum(x.view(-1)[0] for x in self.parameters()) * 0.
+                roi_feats += sum(
+                    x.view(-1)[0]
+                    for x in self.parameters()) * 0. + feats[i].sum() * 0.
         return roi_feats
